from setuptools import setup

setup()

# setup(
#    name='cycoda',
#    version='0.0.1',
#    author="Hannah-Marie Martiny",
#    packages=["cycoda"],
#    author_email="hanmar@food.dtu.dk",
#    install_requires=['numpy', 'pandas', 'umap', 'GPUtil', 'scipy'],
#    long_description=open('README.md').read(),
#    url="https://github.com/hmmartiny/cycoda",
#    extras_require={"GPU":  ['cupy']},

# )
